@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.scheduler_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -171,9 +182,9 @@ class CloudSchedulerAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, CloudSchedulerTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the cloud scheduler client.
@@ -217,11 +228,11 @@ class CloudSchedulerAsyncClient:
 
     async def list_jobs(
         self,
-        request: Union[cloudscheduler.ListJobsRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.ListJobsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListJobsAsyncPager:
         r"""Lists jobs.
@@ -254,7 +265,7 @@ class CloudSchedulerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1.types.ListJobsRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1.types.ListJobsRequest, dict]]):
                 The request object. Request message for listing jobs
                 using
                 [ListJobs][google.cloud.scheduler.v1.CloudScheduler.ListJobs].
@@ -343,11 +354,11 @@ class CloudSchedulerAsyncClient:
 
     async def get_job(
         self,
-        request: Union[cloudscheduler.GetJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.GetJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> job.Job:
         r"""Gets a job.
@@ -379,7 +390,7 @@ class CloudSchedulerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1.types.GetJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1.types.GetJobRequest, dict]]):
                 The request object. Request message for
                 [GetJob][google.cloud.scheduler.v1.CloudScheduler.GetJob].
             name (:class:`str`):
@@ -456,12 +467,12 @@ class CloudSchedulerAsyncClient:
 
     async def create_job(
         self,
-        request: Union[cloudscheduler.CreateJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.CreateJobRequest, dict]] = None,
         *,
-        parent: str = None,
-        job: gcs_job.Job = None,
+        parent: Optional[str] = None,
+        job: Optional[gcs_job.Job] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcs_job.Job:
         r"""Creates a job.
@@ -493,7 +504,7 @@ class CloudSchedulerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1.types.CreateJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1.types.CreateJobRequest, dict]]):
                 The request object. Request message for
                 [CreateJob][google.cloud.scheduler.v1.CloudScheduler.CreateJob].
             parent (:class:`str`):
@@ -575,12 +586,12 @@ class CloudSchedulerAsyncClient:
 
     async def update_job(
         self,
-        request: Union[cloudscheduler.UpdateJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.UpdateJobRequest, dict]] = None,
         *,
-        job: gcs_job.Job = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        job: Optional[gcs_job.Job] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcs_job.Job:
         r"""Updates a job.
@@ -622,7 +633,7 @@ class CloudSchedulerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1.types.UpdateJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1.types.UpdateJobRequest, dict]]):
                 The request object. Request message for
                 [UpdateJob][google.cloud.scheduler.v1.CloudScheduler.UpdateJob].
             job (:class:`google.cloud.scheduler_v1.types.Job`):
@@ -703,11 +714,11 @@ class CloudSchedulerAsyncClient:
 
     async def delete_job(
         self,
-        request: Union[cloudscheduler.DeleteJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.DeleteJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a job.
@@ -736,7 +747,7 @@ class CloudSchedulerAsyncClient:
                 await client.delete_job(request=request)
 
         Args:
-            request (Union[google.cloud.scheduler_v1.types.DeleteJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1.types.DeleteJobRequest, dict]]):
                 The request object. Request message for deleting a job
                 using
                 [DeleteJob][google.cloud.scheduler.v1.CloudScheduler.DeleteJob].
@@ -804,11 +815,11 @@ class CloudSchedulerAsyncClient:
 
     async def pause_job(
         self,
-        request: Union[cloudscheduler.PauseJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.PauseJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> job.Job:
         r"""Pauses a job.
@@ -851,7 +862,7 @@ class CloudSchedulerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1.types.PauseJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1.types.PauseJobRequest, dict]]):
                 The request object. Request message for
                 [PauseJob][google.cloud.scheduler.v1.CloudScheduler.PauseJob].
             name (:class:`str`):
@@ -918,11 +929,11 @@ class CloudSchedulerAsyncClient:
 
     async def resume_job(
         self,
-        request: Union[cloudscheduler.ResumeJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.ResumeJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> job.Job:
         r"""Resume a job.
@@ -964,7 +975,7 @@ class CloudSchedulerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1.types.ResumeJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1.types.ResumeJobRequest, dict]]):
                 The request object. Request message for
                 [ResumeJob][google.cloud.scheduler.v1.CloudScheduler.ResumeJob].
             name (:class:`str`):
@@ -1031,11 +1042,11 @@ class CloudSchedulerAsyncClient:
 
     async def run_job(
         self,
-        request: Union[cloudscheduler.RunJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.RunJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> job.Job:
         r"""Forces a job to run now.
@@ -1069,7 +1080,7 @@ class CloudSchedulerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1.types.RunJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1.types.RunJobRequest, dict]]):
                 The request object. Request message for forcing a job to
                 run now using
                 [RunJob][google.cloud.scheduler.v1.CloudScheduler.RunJob].
@@ -1142,14 +1153,9 @@ class CloudSchedulerAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-scheduler",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("CloudSchedulerAsyncClient",)
