@@ -13,28 +13,33 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from google.cloud.scheduler import gapic_version as package_version
 
-from .services.cloud_scheduler import CloudSchedulerClient
-from .services.cloud_scheduler import CloudSchedulerAsyncClient
+__version__ = package_version.__version__
 
-from .types.cloudscheduler import CreateJobRequest
-from .types.cloudscheduler import DeleteJobRequest
-from .types.cloudscheduler import GetJobRequest
-from .types.cloudscheduler import ListJobsRequest
-from .types.cloudscheduler import ListJobsResponse
-from .types.cloudscheduler import PauseJobRequest
-from .types.cloudscheduler import ResumeJobRequest
-from .types.cloudscheduler import RunJobRequest
-from .types.cloudscheduler import UpdateJobRequest
-from .types.job import Job
-from .types.job import RetryConfig
-from .types.target import AppEngineHttpTarget
-from .types.target import AppEngineRouting
-from .types.target import HttpTarget
-from .types.target import OAuthToken
-from .types.target import OidcToken
-from .types.target import PubsubTarget
-from .types.target import HttpMethod
+
+from .services.cloud_scheduler import CloudSchedulerAsyncClient, CloudSchedulerClient
+from .types.cloudscheduler import (
+    CreateJobRequest,
+    DeleteJobRequest,
+    GetJobRequest,
+    ListJobsRequest,
+    ListJobsResponse,
+    PauseJobRequest,
+    ResumeJobRequest,
+    RunJobRequest,
+    UpdateJobRequest,
+)
+from .types.job import Job, RetryConfig
+from .types.target import (
+    AppEngineHttpTarget,
+    AppEngineRouting,
+    HttpMethod,
+    HttpTarget,
+    OAuthToken,
+    OidcToken,
+    PubsubTarget,
+)
 
 __all__ = (
     "CloudSchedulerAsyncClient",
