@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,13 +34,15 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.scheduler_v1beta1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.cloud.location import locations_pb2  # type: ignore
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -171,9 +183,9 @@ class CloudSchedulerAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, CloudSchedulerTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the cloud scheduler client.
@@ -217,11 +229,11 @@ class CloudSchedulerAsyncClient:
 
     async def list_jobs(
         self,
-        request: Union[cloudscheduler.ListJobsRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.ListJobsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListJobsAsyncPager:
         r"""Lists jobs.
@@ -254,7 +266,7 @@ class CloudSchedulerAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1beta1.types.ListJobsRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1beta1.types.ListJobsRequest, dict]]):
                 The request object. Request message for listing jobs
                 using
                 [ListJobs][google.cloud.scheduler.v1beta1.CloudScheduler.ListJobs].
@@ -274,7 +286,7 @@ class CloudSchedulerAsyncClient:
         Returns:
             google.cloud.scheduler_v1beta1.services.cloud_scheduler.pagers.ListJobsAsyncPager:
                 Response message for listing jobs using
-                [ListJobs][google.cloud.scheduler.v1beta1.CloudScheduler.ListJobs].
+                   [ListJobs][google.cloud.scheduler.v1beta1.CloudScheduler.ListJobs].
 
                 Iterating over this object will yield results and
                 resolve additional pages automatically.
@@ -343,11 +355,11 @@ class CloudSchedulerAsyncClient:
 
     async def get_job(
         self,
-        request: Union[cloudscheduler.GetJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.GetJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> job.Job:
         r"""Gets a job.
@@ -379,7 +391,7 @@ class CloudSchedulerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1beta1.types.GetJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1beta1.types.GetJobRequest, dict]]):
                 The request object. Request message for
                 [GetJob][google.cloud.scheduler.v1beta1.CloudScheduler.GetJob].
             name (:class:`str`):
@@ -399,7 +411,7 @@ class CloudSchedulerAsyncClient:
             google.cloud.scheduler_v1beta1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
         """
         # Create or coerce a protobuf request object.
@@ -456,12 +468,12 @@ class CloudSchedulerAsyncClient:
 
     async def create_job(
         self,
-        request: Union[cloudscheduler.CreateJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.CreateJobRequest, dict]] = None,
         *,
-        parent: str = None,
-        job: gcs_job.Job = None,
+        parent: Optional[str] = None,
+        job: Optional[gcs_job.Job] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcs_job.Job:
         r"""Creates a job.
@@ -493,7 +505,7 @@ class CloudSchedulerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1beta1.types.CreateJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1beta1.types.CreateJobRequest, dict]]):
                 The request object. Request message for
                 [CreateJob][google.cloud.scheduler.v1beta1.CloudScheduler.CreateJob].
             parent (:class:`str`):
@@ -527,7 +539,7 @@ class CloudSchedulerAsyncClient:
             google.cloud.scheduler_v1beta1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
         """
         # Create or coerce a protobuf request object.
@@ -576,12 +588,12 @@ class CloudSchedulerAsyncClient:
 
     async def update_job(
         self,
-        request: Union[cloudscheduler.UpdateJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.UpdateJobRequest, dict]] = None,
         *,
-        job: gcs_job.Job = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        job: Optional[gcs_job.Job] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcs_job.Job:
         r"""Updates a job.
@@ -623,7 +635,7 @@ class CloudSchedulerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1beta1.types.UpdateJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1beta1.types.UpdateJobRequest, dict]]):
                 The request object. Request message for
                 [UpdateJob][google.cloud.scheduler.v1beta1.CloudScheduler.UpdateJob].
             job (:class:`google.cloud.scheduler_v1beta1.types.Job`):
@@ -655,7 +667,7 @@ class CloudSchedulerAsyncClient:
             google.cloud.scheduler_v1beta1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
         """
         # Create or coerce a protobuf request object.
@@ -704,11 +716,11 @@ class CloudSchedulerAsyncClient:
 
     async def delete_job(
         self,
-        request: Union[cloudscheduler.DeleteJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.DeleteJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
         r"""Deletes a job.
@@ -737,7 +749,7 @@ class CloudSchedulerAsyncClient:
                 await client.delete_job(request=request)
 
         Args:
-            request (Union[google.cloud.scheduler_v1beta1.types.DeleteJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1beta1.types.DeleteJobRequest, dict]]):
                 The request object. Request message for deleting a job
                 using
                 [DeleteJob][google.cloud.scheduler.v1beta1.CloudScheduler.DeleteJob].
@@ -805,11 +817,11 @@ class CloudSchedulerAsyncClient:
 
     async def pause_job(
         self,
-        request: Union[cloudscheduler.PauseJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.PauseJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> job.Job:
         r"""Pauses a job.
@@ -852,7 +864,7 @@ class CloudSchedulerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1beta1.types.PauseJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1beta1.types.PauseJobRequest, dict]]):
                 The request object. Request message for
                 [PauseJob][google.cloud.scheduler.v1beta1.CloudScheduler.PauseJob].
             name (:class:`str`):
@@ -872,7 +884,7 @@ class CloudSchedulerAsyncClient:
             google.cloud.scheduler_v1beta1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
         """
         # Create or coerce a protobuf request object.
@@ -929,11 +941,11 @@ class CloudSchedulerAsyncClient:
 
     async def resume_job(
         self,
-        request: Union[cloudscheduler.ResumeJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.ResumeJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> job.Job:
         r"""Resume a job.
@@ -975,7 +987,7 @@ class CloudSchedulerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1beta1.types.ResumeJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1beta1.types.ResumeJobRequest, dict]]):
                 The request object. Request message for
                 [ResumeJob][google.cloud.scheduler.v1beta1.CloudScheduler.ResumeJob].
             name (:class:`str`):
@@ -995,7 +1007,7 @@ class CloudSchedulerAsyncClient:
             google.cloud.scheduler_v1beta1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
         """
         # Create or coerce a protobuf request object.
@@ -1052,11 +1064,11 @@ class CloudSchedulerAsyncClient:
 
     async def run_job(
         self,
-        request: Union[cloudscheduler.RunJobRequest, dict] = None,
+        request: Optional[Union[cloudscheduler.RunJobRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> job.Job:
         r"""Forces a job to run now.
@@ -1090,7 +1102,7 @@ class CloudSchedulerAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.scheduler_v1beta1.types.RunJobRequest, dict]):
+            request (Optional[Union[google.cloud.scheduler_v1beta1.types.RunJobRequest, dict]]):
                 The request object. Request message for forcing a job to
                 run now using
                 [RunJob][google.cloud.scheduler.v1beta1.CloudScheduler.RunJob].
@@ -1111,7 +1123,7 @@ class CloudSchedulerAsyncClient:
             google.cloud.scheduler_v1beta1.types.Job:
                 Configuration for a job.
                 The maximum allowed size for a job is
-                100KB.
+                1MB.
 
         """
         # Create or coerce a protobuf request object.
@@ -1156,6 +1168,114 @@ class CloudSchedulerAsyncClient:
         # Done; return the response.
         return response
 
+    async def get_location(
+        self,
+        request: Optional[locations_pb2.GetLocationRequest] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> locations_pb2.Location:
+        r"""Gets information about a location.
+
+        Args:
+            request (:class:`~.location_pb2.GetLocationRequest`):
+                The request object. Request message for
+                `GetLocation` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                 if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.location_pb2.Location:
+                Location object.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = locations_pb2.GetLocationRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._client._transport.get_location,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    async def list_locations(
+        self,
+        request: Optional[locations_pb2.ListLocationsRequest] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> locations_pb2.ListLocationsResponse:
+        r"""Lists information about the supported locations for this service.
+
+        Args:
+            request (:class:`~.location_pb2.ListLocationsRequest`):
+                The request object. Request message for
+                `ListLocations` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                 if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.location_pb2.ListLocationsResponse:
+                Response message for ``ListLocations`` method.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = locations_pb2.ListLocationsRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._client._transport.list_locations,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
     async def __aenter__(self):
         return self
 
@@ -1163,14 +1283,9 @@ class CloudSchedulerAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-scheduler",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("CloudSchedulerAsyncClient",)
