@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 from google.rpc import status_pb2  # type: ignore
@@ -31,7 +33,7 @@ __protobuf__ = proto.module(
 
 class Job(proto.Message):
     r"""Configuration for a job.
-    The maximum allowed size for a job is 100KB.
+    The maximum allowed size for a job is 1MB.
 
     This message has `oneof`_ fields (mutually exclusive fields).
     For each oneof, at most one member field can be set at the same time.
@@ -90,7 +92,7 @@ class Job(proto.Message):
 
             The schedule can be either of the following types:
 
-            -  `Crontab <http://en.wikipedia.org/wiki/Cron#Overview>`__
+            -  `Crontab <https://en.wikipedia.org/wiki/Cron#Overview>`__
             -  English-like
                `schedule <https://cloud.google.com/scheduler/docs/configuring/cron-job-schedules>`__
 
@@ -147,17 +149,35 @@ class Job(proto.Message):
             Cloud Scheduler will retry the job according to the
             [RetryConfig][google.cloud.scheduler.v1beta1.RetryConfig].
 
-            The allowed duration for this deadline is:
+            The default and the allowed values depend on the type of
+            target:
 
             -  For [HTTP
                targets][google.cloud.scheduler.v1beta1.Job.http_target],
-               between 15 seconds and 30 minutes.
+               the default is 3 minutes. The deadline must be in the
+               interval [15 seconds, 30 minutes].
+
             -  For [App Engine HTTP
                targets][google.cloud.scheduler.v1beta1.Job.app_engine_http_target],
-               between 15 seconds and 24 hours.
-            -  For [PubSub
+               0 indicates that the request has the default deadline.
+               The default deadline depends on the scaling type of the
+               service: 10 minutes for standard apps with automatic
+               scaling, 24 hours for standard apps with manual and basic
+               scaling, and 60 minutes for flex apps. If the request
+               deadline is set, it must be in the interval [15 seconds,
+               24 hours 15 seconds].
+
+            -  For [Pub/Sub
                targets][google.cloud.scheduler.v1beta1.Job.pubsub_target],
                this field is ignored.
+        legacy_app_engine_cron (bool):
+            Immutable. This field is used to manage the
+            legacy App Engine Cron jobs using the Cloud
+            Scheduler API. If the field is set to true, the
+            job will be considered a legacy job. Note that
+            App Engine Cron jobs have fewer features than
+            Cloud Scheduler jobs, e.g., are only limited to
+            App Engine targets.
     """
 
     class State(proto.Enum):
@@ -168,75 +188,79 @@ class Job(proto.Message):
         DISABLED = 3
         UPDATE_FAILED = 4
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    description = proto.Field(
+    description: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    pubsub_target = proto.Field(
+    pubsub_target: target.PubsubTarget = proto.Field(
         proto.MESSAGE,
         number=4,
         oneof="target",
         message=target.PubsubTarget,
     )
-    app_engine_http_target = proto.Field(
+    app_engine_http_target: target.AppEngineHttpTarget = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="target",
         message=target.AppEngineHttpTarget,
     )
-    http_target = proto.Field(
+    http_target: target.HttpTarget = proto.Field(
         proto.MESSAGE,
         number=6,
         oneof="target",
         message=target.HttpTarget,
     )
-    schedule = proto.Field(
+    schedule: str = proto.Field(
         proto.STRING,
         number=20,
     )
-    time_zone = proto.Field(
+    time_zone: str = proto.Field(
         proto.STRING,
         number=21,
     )
-    user_update_time = proto.Field(
+    user_update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=9,
         message=timestamp_pb2.Timestamp,
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=10,
         enum=State,
     )
-    status = proto.Field(
+    status: status_pb2.Status = proto.Field(
         proto.MESSAGE,
         number=11,
         message=status_pb2.Status,
     )
-    schedule_time = proto.Field(
+    schedule_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=17,
         message=timestamp_pb2.Timestamp,
     )
-    last_attempt_time = proto.Field(
+    last_attempt_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=18,
         message=timestamp_pb2.Timestamp,
     )
-    retry_config = proto.Field(
+    retry_config: "RetryConfig" = proto.Field(
         proto.MESSAGE,
         number=19,
         message="RetryConfig",
     )
-    attempt_deadline = proto.Field(
+    attempt_deadline: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=22,
         message=duration_pb2.Duration,
     )
+    legacy_app_engine_cron: bool = proto.Field(
+        proto.BOOL,
+        number=23,
+    )
 
 
 class RetryConfig(proto.Message):
@@ -290,7 +314,7 @@ class RetryConfig(proto.Message):
             A job's retry interval starts at
             [min_backoff_duration][google.cloud.scheduler.v1beta1.RetryConfig.min_backoff_duration],
             then doubles ``max_doublings`` times, then increases
-            linearly, and finally retries retries at intervals of
+            linearly, and finally retries at intervals of
             [max_backoff_duration][google.cloud.scheduler.v1beta1.RetryConfig.max_backoff_duration]
             up to
             [retry_count][google.cloud.scheduler.v1beta1.RetryConfig.retry_count]
@@ -313,26 +337,26 @@ class RetryConfig(proto.Message):
             The default value of this field is 5.
     """
 
-    retry_count = proto.Field(
+    retry_count: int = proto.Field(
         proto.INT32,
         number=1,
     )
-    max_retry_duration = proto.Field(
+    max_retry_duration: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=2,
         message=duration_pb2.Duration,
     )
-    min_backoff_duration = proto.Field(
+    min_backoff_duration: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=3,
         message=duration_pb2.Duration,
     )
-    max_backoff_duration = proto.Field(
+    max_backoff_duration: duration_pb2.Duration = proto.Field(
         proto.MESSAGE,
         number=4,
         message=duration_pb2.Duration,
     )
-    max_doublings = proto.Field(
+    max_doublings: int = proto.Field(
         proto.INT32,
         number=5,
     )
