@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 __protobuf__ = proto.module(
@@ -70,7 +72,7 @@ class HttpTarget(proto.Message):
             characters after encoding.
         http_method (google.cloud.scheduler_v1beta1.types.HttpMethod):
             Which HTTP method to use for the request.
-        headers (Mapping[str, str]):
+        headers (MutableMapping[str, str]):
             The user can specify HTTP request headers to send with the
             job's HTTP request. This map contains the header field names
             and values. Repeated headers are not supported, but a header
@@ -90,6 +92,13 @@ class HttpTarget(proto.Message):
                ``"Google-Cloud-Scheduler"``.
             -  ``X-Google-*``: Google internal use only.
             -  ``X-AppEngine-*``: Google internal use only.
+            -  ``X-CloudScheduler``: This header will be set to true.
+            -  ``X-CloudScheduler-JobName``: This header will contain
+               the job name.
+            -  ``X-CloudScheduler-ScheduleTime``: For Cloud Scheduler
+               jobs specified in the unix-cron format, this header will
+               contain the job schedule time in RFC3339 UTC "Zulu"
+               format.
 
             The total size of headers must be less than 80KB.
         body (bytes):
@@ -120,31 +129,31 @@ class HttpTarget(proto.Message):
             This field is a member of `oneof`_ ``authorization_header``.
     """
 
-    uri = proto.Field(
+    uri: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    http_method = proto.Field(
+    http_method: "HttpMethod" = proto.Field(
         proto.ENUM,
         number=2,
         enum="HttpMethod",
     )
-    headers = proto.MapField(
+    headers: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=3,
     )
-    body = proto.Field(
+    body: bytes = proto.Field(
         proto.BYTES,
         number=4,
     )
-    oauth_token = proto.Field(
+    oauth_token: "OAuthToken" = proto.Field(
         proto.MESSAGE,
         number=5,
         oneof="authorization_header",
         message="OAuthToken",
     )
-    oidc_token = proto.Field(
+    oidc_token: "OidcToken" = proto.Field(
         proto.MESSAGE,
         number=6,
         oneof="authorization_header",
@@ -178,7 +187,7 @@ class AppEngineHttpTarget(proto.Message):
             arguments, and ``#`` fragments. If the relative URL is
             empty, then the root path "/" will be used. No spaces are
             allowed, and the maximum length allowed is 2083 characters.
-        headers (Mapping[str, str]):
+        headers (MutableMapping[str, str]):
             HTTP request headers.
 
             This map contains the header field names and values. Headers
@@ -193,6 +202,12 @@ class AppEngineHttpTarget(proto.Message):
                ``"AppEngine-Google; (+http://code.google.com/appengine)"``
                to the modified ``User-Agent``.
             -  ``X-CloudScheduler``: This header will be set to true.
+            -  ``X-CloudScheduler-JobName``: This header will contain
+               the job name.
+            -  ``X-CloudScheduler-ScheduleTime``: For Cloud Scheduler
+               jobs specified in the unix-cron format, this header will
+               contain the job schedule time in RFC3339 UTC "Zulu"
+               format.
 
             If the job has an
             [body][google.cloud.scheduler.v1beta1.AppEngineHttpTarget.body],
@@ -225,26 +240,26 @@ class AppEngineHttpTarget(proto.Message):
             [HttpMethod][google.cloud.scheduler.v1beta1.HttpMethod].
     """
 
-    http_method = proto.Field(
+    http_method: "HttpMethod" = proto.Field(
         proto.ENUM,
         number=1,
         enum="HttpMethod",
     )
-    app_engine_routing = proto.Field(
+    app_engine_routing: "AppEngineRouting" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="AppEngineRouting",
     )
-    relative_uri = proto.Field(
+    relative_uri: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    headers = proto.MapField(
+    headers: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=4,
     )
-    body = proto.Field(
+    body: bytes = proto.Field(
         proto.BYTES,
         number=5,
     )
@@ -259,7 +274,7 @@ class PubsubTarget(proto.Message):
             Required. The name of the Cloud Pub/Sub topic to which
             messages will be published when a job is delivered. The
             topic name must be in the same format as required by
-            PubSub's
+            Pub/Sub's
             `PublishRequest.name <https://cloud.google.com/pubsub/docs/reference/rpc/google.pubsub.v1#publishrequest>`__,
             for example ``projects/PROJECT_ID/topics/TOPIC_ID``.
 
@@ -269,21 +284,21 @@ class PubsubTarget(proto.Message):
             The message payload for PubsubMessage.
             Pubsub message must contain either non-empty
             data, or at least one attribute.
-        attributes (Mapping[str, str]):
+        attributes (MutableMapping[str, str]):
             Attributes for PubsubMessage.
             Pubsub message must contain either non-empty
             data, or at least one attribute.
     """
 
-    topic_name = proto.Field(
+    topic_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    data = proto.Field(
+    data: bytes = proto.Field(
         proto.BYTES,
         number=3,
     )
-    attributes = proto.MapField(
+    attributes: MutableMapping[str, str] = proto.MapField(
         proto.STRING,
         proto.STRING,
         number=4,
@@ -322,7 +337,7 @@ class AppEngineRouting(proto.Message):
 
             Requests can only be sent to a specific instance if `manual
             scaling is used in App Engine
-            Standard <https://cloud.google.com/appengine/docs/python/an-overview-of-app-engine?hl=en_US#scaling_types_and_instance_classes>`__.
+            Standard <https://cloud.google.com/appengine/docs/python/an-overview-of-app-engine?#scaling_types_and_instance_classes>`__.
             App Engine Flex does not support instances. For more
             information, see `App Engine Standard request
             routing <https://cloud.google.com/appengine/docs/standard/python/how-requests-are-routed>`__
@@ -405,19 +420,19 @@ class AppEngineRouting(proto.Message):
             of the default service when the job is attempted.
     """
 
-    service = proto.Field(
+    service: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    version = proto.Field(
+    version: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    instance = proto.Field(
+    instance: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    host = proto.Field(
+    host: str = proto.Field(
         proto.STRING,
         number=4,
     )
@@ -444,11 +459,11 @@ class OAuthToken(proto.Message):
             will be used.
     """
 
-    service_account_email = proto.Field(
+    service_account_email: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    scope = proto.Field(
+    scope: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -475,11 +490,11 @@ class OidcToken(proto.Message):
             target will be used.
     """
 
-    service_account_email = proto.Field(
+    service_account_email: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    audience = proto.Field(
+    audience: str = proto.Field(
         proto.STRING,
         number=2,
     )
